@@ -5,27 +5,28 @@ from .h5_dataset import H5Dataset
 
 # TODO how to handle multiple resolution? Could use different "from_avocado" methods but then the API will differ between classes.
 
+
 class Kather96x96(H5Dataset):
     """
     Kather dataset, more information can be found at https://zenodo.org/record/1214456
     """
 
-    def __init__(self, root: str, sub_set: str, transform: Optional[Callable] = None, transform_target: Optional[Callable] = None):
+    def __init__(self, root: str, sub_set: str, transform: Optional[Callable] = None, transform_target: Optional[Callable] = None, num_samples: int = 1):
         assert sub_set in ['train', 'valid', 'test']
 
         super().__init__(data_path=Path(root) / f'{sub_set}.h5',
                          data_key='image',
-                         target_path=Path(
-                             root) / f'{sub_set}.h5',
+                         target_path=Path(root) / f'{sub_set}.h5',
                          target_key='label',
                          transform=transform,
-                         transform_target=transform_target)
+                         transform_target=transform_target,
+                         num_samples=num_samples)
 
         self.classes = ['ADI', 'BACK', 'DEB', 'LYM', 'MUC', 'MUS', 'NORM', 'STR', 'TUM']
 
     @classmethod
-    def from_avocado(cls, sub_set: str = 'train', transform: Optional[Callable] = None, transform_target: Optional[Callable] = None):
-        return cls('/data/ldap/histopathologic/processed_read_only/Kather_H5/res96', sub_set, transform,transform_target)
+    def from_avocado(cls, sub_set: str = 'train', transform: Optional[Callable] = None, transform_target: Optional[Callable] = None, num_samples: int = 1):
+        return cls('/data/ldap/histopathologic/processed_read_only/Kather_H5/res96', sub_set, transform, transform_target, num_samples=num_samples)
 
     @staticmethod
     def normalization_values():
@@ -34,6 +35,7 @@ class Kather96x96(H5Dataset):
         std = [0.2154, 0.2781, 0.2226]
         return mean, std
 
+
 class Kather224x224(H5Dataset):
     """
     Kather dataset, more information can be found at https://zenodo.org/record/1214456
@@ -44,8 +46,7 @@ class Kather224x224(H5Dataset):
 
         super().__init__(data_path=Path(root) / f'{sub_set}.h5',
                          data_key='image',
-                         target_path=Path(
-                             root) / f'{sub_set}.h5',
+                         target_path=Path(root) / f'{sub_set}.h5',
                          target_key='label',
                          transform=transform,
                          transform_target=transform_target)
@@ -62,4 +63,4 @@ class Kather224x224(H5Dataset):
         mean = [0.7357, 0.5804, 0.7013]
         std = [0.2261, 0.2857, 0.2297]
         return mean, std
-    
\ No newline at end of file
+    
